#
# spec file for package pure-ftpd
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# check if oes specific patches will be applied or not
%define with_oes 0

Name:           pure-ftpd
Version:        1.0.29
Release:        8.11.1
License:        BSD3c
Summary:        A Lightweight, Fast, and Secure FTP Server
Url:            http://www.pureftpd.org
Group:          Productivity/Networking/Ftp/Servers
Source:         ftp://ftp.pureftpd.org/pub/%{name}/releases/%{name}-%version.tar.bz2
Source1:        %{name}.init
Source2:        %{name}.pamd
Source3:        %{name}.xinetd
Source4:        %{name}.xml
Source5:        %{name}.firewall
# PATCH-FEATURE-OPENSUSE %{name}-1.0.20_config.patch -- Custom service configs.
Patch:          %{name}-1.0.20_config.patch
# PATCH-FEATURE-OPENSUSE %{name}-1.0.20_doc.patch -- Adjust command paths on documentation.
Patch1:         %{name}-1.0.20_doc.patch
# PATCH-FEATURE-OPENSUSE %{name}-1.0.20_virtualhosts.patch -- Custom VHOST_PATH on openSUSE.
Patch2:         %{name}-1.0.20_virtualhosts.patch
Patch5:         %{name}-1.0.20_ftpwho_path.patch
Patch7:         %{name}-1.0.22-default_tcp_sedrcv_buffer_size.patch
# PATCH-FEATURE-OPENSUSE %{name}-1.0.21-portrange.patch -- Add PassivePortRange to "%numpairc_switch_for".
Patch8:         %{name}-1.0.21-portrange.patch
#PATCH-FIX-UPSTREAM: 
#https://github.com/jedisct1/pure-ftpd/commit/65c4d4ad331e94661de763e9b5304d28698999c4
Patch9:         pure-ftpd-1.0.29-flush-cmd-after-tls.patch
#PATCH-FIX-UPSTREAM: bnc#700611
#https://github.com/jedisct1/pure-ftpd/commit/ac36eb8dd05506b0ffdd78e2f2e85a7ecc9f0fbb
Patch10:        pure-ftpd-1.0.32-cap-audit-write.patch
# OES patches - see %with_oes
Patch100:       %{name}-1.0.20-oes_remote_server.patch
Patch101:       pure-ftpd-1.0.22-oes-bugfix-534424.patch
BuildRequires:  mysql-devel
BuildRequires:  openldap2-devel
BuildRequires:  pam-devel
BuildRequires:  postgresql-devel
BuildRequires:  libcap-devel
PreReq:         %insserv_prereq
PreReq:         coreutils
Provides:       ftp-server
Provides:       pureftpd
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Pure-FTPd is a fast, production-quality, and standard-conforming FTP
server, based-on Troll-FTPd. Unlike other popular FTP servers, it has
no known security flaws, is trivial to set up, and is especially
designed for modern Linux kernels (setfsuid and sendfile capabilities)
. Features include: PAM support, IPv6, chroot()ed home directories,
virtual domains, built-in LS, anti-warez system, bandwidth throttling,
FXP, bounded ports for passive downloads, upload and download ratios,
Apache log files, and more.

%prep
%setup -q
%patch
%patch1
%patch2
%patch5
%patch7
%patch8
%patch9 -p1
%patch10 -p1
# uncomment this if you want to have the OES remote_server feature
%if %{with_oes}
%patch100 -p0
%patch101 -p1
%endif

%build
CFLAGS="%{optflags} -DLDAP_DEPRECATED -fstack-protector"
%configure --with-rfc2640 \
	--sysconfdir=%{_sysconfdir}/%{name} \
	--with-ldap \
	--with-paranoidmsg \
	--with-altlog \
	--with-virtualhosts \
	--with-ftpwho \
	--with-mysql \
	--with-nonalnum \
	--with-pgsql \
	--with-cookie \
	--with-throttling \
	--with-ratios \
	--with-uploadscript \
	--with-diraliases \
	--with-pam \
	--with-puredb \
	--with-sysquotas \
	--with-quotas \
	--with-inetd \
	--with-tls \
	--with-boring \
	--with-peruserlimits \
	--with-largefile %_target_cpu-suse-linux \
	--with-virtualchroot
%{__make}
cat configuration-file/pure-config.pl |grep -v "^print" | grep -v "^exec" > configuration-file/pure-config-args
echo "print join(\" \", @flg);" >> configuration-file/pure-config-args

%install
%makeinstall
%{__install} -dD -m 0755 \
    %{buildroot}%{_sysconfdir}/{init.d,%{name},%{name}/vhosts,pam.d,xinetd.d,openldap/schema}
%{__install} -m 0755 \
        configuration-file/pure-config.pl \
        configuration-file/pure-config-args \
    %{buildroot}%{_sbindir}
%{__install} -m 0644 configuration-file/pure-ftpd.conf \
               %{buildroot}%{_sysconfdir}/%{name}
%{__install} -m 0755 %{S:1} %{buildroot}%{_sysconfdir}/init.d/%{name}
ln -sf /etc/init.d/%{name}  %{buildroot}%{_sbindir}/rc%{name}
%{__install} -m 0644 %{S:2}          %{buildroot}%{_sysconfdir}/pam.d/pure-ftpd
%{__install} -m 0644 %{S:3}          %{buildroot}%{_sysconfdir}/xinetd.d/pure-ftpd
%{__install} -m 0644 pureftpd.schema %{buildroot}%{_sysconfdir}/openldap/schema/
%{__install} -d						 %{buildroot}%{_datadir}/omc/svcinfo.d/
%{__install} -m 0644 %{S:4}			 %{buildroot}%{_datadir}/omc/svcinfo.d/
%{__install} -d						 %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/
%{__install} -m 644 %{S:5}			 %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%name

%clean
%{__rm} -rf %{buildroot}

%preun
%stop_on_removal %{name}

%post
if [ -f etc/pure-ftpd.conf ]; then
        mv etc/pure-ftpd.conf etc/pure-ftpd/pure-ftpd.conf
fi

%postun
%insserv_cleanup
%restart_on_update %{name}

%files
%defattr(-, root, root)
%{_datadir}/omc/svcinfo.d/%name.xml
%doc AUTHORS CONTACT COPYING NEWS THANKS README README.Contrib
%doc README.Configuration-File HISTORY README.Virtual-Users
%doc README.LDAP pureftpd-ldap.conf README.MySQL README.PGSQL README.TLS
%{_mandir}/man8/*
%{_bindir}/*
%{_sbindir}/*
%dir %{_sysconfdir}/openldap
%dir %{_sysconfdir}/openldap/schema
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/vhosts
%config %{_sysconfdir}/openldap/schema/pureftpd.schema
%config %{_sysconfdir}/init.d/pure-ftpd
%config %{_sysconfdir}/pam.d/pure-ftpd
%config(noreplace) %{_sysconfdir}/%{name}/pure-ftpd.conf
%config(noreplace) %{_sysconfdir}/xinetd.d/pure-ftpd
%config(noreplace) %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%name

%changelog
* Wed Jun 22 2011 mvyskocil@suse.cz
- fix bnc#700611 - pure-ftpd fails with pam
  * pure-ftpd-1.0.32-cap-audit-write.patch
* Mon Apr 11 2011 mvyskocil@suse.cz
- fix bnc#686590 - VUL-0: new pure-ftpd version fix STARTTLS issues similar to
  CVE-2011-0411
  * flush command buffer after switch to TLS
* Thu Oct  7 2010 mvyskocil@suse.cz
- add pure-ftpd-1.0.22-oes-bugfix-534424.patch for tracking OES patches
- use macro with_oes to determine if OES patches might be applied or not
* Tue Sep 14 2010 cristian.rodriguez@opensuse.org
- Use with-rfc2640 [bnc#638626]
* Tue Jul 20 2010 cristian.rodriguez@opensuse.org
- add missing buildRequires on libcap-devel
* Tue May 25 2010 cristian.rodriguez@opensuse.org
- $remote_fs --> network-remotefs
* Fri May 14 2010 alexandre@exatati.com.br
- Added "--with-virtualchroot" option;
- Spec file cleaned with spec-cleaner;
- updated to version 1.0.29:
  - max_dlmap_size was size_t instead off_t, causing misalignment while
    downloading > 4 Gb files on a 32-bits arch.
  - pread() vs lseek()+read() was a useless optimization, since pread()
    doesn't change the file position and further reads weren't going through
    plain read() calls.
  - iconv_fd_* should be initialized by (iconv_t) -1 as we test them upon
    exit. Fixes segfaults on glibc.
  - pure-uploadscript tries to reach the pipe during 30 seconds instead of 10.
- changes in version 1.0.28:
  - FTPD_PAM_SERVICE_NAME can be defined in order to change the PAM service
    name.
  - When an upload gets renamed (--autorename), send the new name to the
    uploadscript instead of the original one.
  - The ALLO command now checks for the actual disk space in addition to the
    virtal quota.
  - Work around OSX broken poll()
  - After an atomic resumed upload, don't append the previous file size to the
    quota.
  - Always accept OPTS UTF8 ON, but refuse OPTS UTF8 OFF if client_charset is
    UTF8.
  - Fix AUTHD_ENCRYPTED
  - Reset the CWD failures counter after a successful directory has been
    created. It avoids spurious disconnections with ncftp.
  - Support for iPhone has been moved to another branch.
  - Fix crash with PostgreSQL.
* Fri Feb 12 2010 mseben@novell.com
- updated to version 1.0.27:
  - Have pureftpd_shutdown() shut the server down even if a client is
  connected on iPhone.
  - Allow users with no quota to delete .pureftpd-upload-* files.
  - Unbreak ipv6 support, reported by Brad Smith.
  - Disable SSLv3 renegotiation if an old SSL library is used. If you really
  want to re-enable SSLv3 renegotiation, even with a recent library, you can
  always define ACCEPT_SSL_RENEGOTIATION.
- changes in version 1.0.26:
  - Fix incompatibilities with Cyberduck when TLS is enabled.
  - Don't TLS_accept() immediately after accept(). Reply on the connection
  socket first, so that clients don't have to wait before knowing that they
  can actually use TLS. It avoids lags with LFTP and hangs with Cyberduck.
  - Properly change the process name on Linux when the -S option is used, by
  Margus Kaidja.
  - Unbreak authentication of non-chrooted users. Thanks to Juergen Daubert
  for the bug report.
- changes in version 1.0.25:
  - Show symlinks as symlinks in MLSD, except when the broken client
  compatibility mode is turned on and links are not dangling (just like the
  old LIST and NLIST commands). Reported by Mime Cuvalo.
  - More gcc 2 compatibility, thanks to Todd Rinaldo.
  - Properly handle custom paths in man pages. Thanks to Scott Haneda and
  Mathieu Parisot.
  - Have $localstatedir default to /var as it used to be unless
  - -localstatedir=... is explicitely passed to ./configure
  - Use @VERSION@ in man pages.
  - --without-pam disables PAM on OSX and iPhone.
  - Allow cross-compilation.
  - Experimental iPhone target.
  - Change the way it links, building a library first.
  - Don't use mmap() any more for downloads. It's too slow.
  - Don't use hard-coded paths in order to find MySQL and PostgreSQL
  libraries and header files. Use mysql_config and pg_config instead.
  Suggested by John Alberts.
  - Log the DELE command similar to the RETR and STOR commands. Suggested by
  Martin Fuxa.
  - The primary group gets cached so that it's always displayed in directory
  listings.
  - Avoid a client process to burn CPU in an infinite loop if the command
  channel gets disconnected before the data channel. Reported by Thomas Min
  and Margus Kaidja.
  - Restore the traditional behavior of a download restarting at the end of a
  file. For some weird reasons, some clients still insist on doing that. Don't
  send a 55x return code, just let them download... nothing.
  - Documentation updates.
- changes in version 1.0.24:
  - Refuse empty passwords in LDAP bind mode. Reported by Henning Brauer.
  - The package can now be compiled with gcc 2.
- changes in version 1.0.23:
  - LDAP: accept "enabled" as a correct value for FTPStatus as it used to be.
  - More useful error logging for OpenSSL errors.
  - Don't read certificates twice.
  - Fix compilation on Solaris with privsep, thanks to Ritesh Patel.
  - Don't replace : (as in IPv6 addresses) in host names. Thanks to Tero Pelander.
  - Add SUP top AUXILIARY to LDAP schema, suggested by Zhang Huangbin.
  - Don't ignore dot files even if -D is not supplied with the MLSD command.
  - Deinline code
  - Throttling more reliable
  - STAT is now working over TLS
  - DH keys for ephemeral key exchange are now handled
  - Fix libiconv checking
  - The column was missing in the PassivePortRange comment (thanks to Igor Alexadrov)
  - LDAP authentication through binding is now possible in addition to
  passwords. This allows for the FTP server to run with an unprivileged LDAP
  account. It also adds a warning if auth method password is used and doesn't find
  a userPassword attribute. This usually indicates that the LDAP bind DN
  cannot read the attributes, because it doesn't have sufficient privileges.
  Contributed by Wilco Baan Hofman.
  - Perform charset conversions on directory names. Issue spotted by Xianghu Zhao.
  - Almost a complete rewrite of the upload, download and TLS code for more
  reliability
  - Seemlessly handle ABOR without any SIGURG
  - Try to immediately handle any kind of disconnection
  - Use poll() rather than select() as much as possible
  - Distinguish aborted (even the hard way) and completed download and upload
  operations in log files
  - Minor corrections to he French messages
  - Don't use atomic uploads unless --notruncate or --autorename have been
  enabled
  - Take care of removing .pureftpd-upload-* files in every possible case
  - List up to 10000 files per directory per default instead of 2000
  - Don't mess with TCP_NOPUSH, as it interferes with OpenSSL
  - New compile-time option: --with-implicittls in order to build a FTPS-only
  server
  - ./configure --localstatedir can now be used in order to avoid storing the
  scoreboard and other dynamic files in /var/run/
  - Quota handling reworked (easier, and way more reliable)
  - RNTO support even when quota are enabled.
  - A bunch of return codes were fixed to be more RFC-conformant.
  - ALLO command is now actually checking if an upload can occur without
  blowing the quota.
  - Don't change the TCP window size. Admins should do this as part of their
  system configuration.
  - Privsep is now enabled by default. Use --without-privsep to disable.
  - --without-banner is gone. If you have a cookie file (-F), the default
  banner won't be displayed.
  - Compile with PAM by default on OSX.
  - Switch the privsep process to _pure-ftpd or pure-ftpd when no privileged
  call is actually necessary. Since only the effective uid chances, it's not
  brutally useful yet, but it paves the way for forthcoming changes.
  - Install man pages with local paths instead of hard-coded ones.
* Tue Jan 12 2010 mseben@novell.com
- modified portrange.patch - for PassivePortRange option in pure-ftpd.conf
  we could use now also syntax without colon (bnc#547578)
- merged config.patch with config_minuid.patch
* Fri Jun  5 2009 coolo@novell.com
- fix build
* Mon May 25 2009 hvogel@suse.de
- Update to version 1.0.22
  - New catalan translation
  - TLS support for LDAP
  - Fix usage of MySQL 5 stored procedures
  - Compatibility with newer OpenLDAP versions
  - Don't hang up during uploads if we get any other command than QUIT and
  ABORT.
  - SITE UTIME reads UTC time
  - A space is needed for inline content in response to the MLST command.
  - Time zone issues should be fixed for good. We have to redefine TZ,
  tzset() is not enough on Linux when we are in a chroot environment.
  - Correctly respond to FEAT without removing extra features when passive
  mode is disabled. Thanks to upb.
  - Better process name change setup for Linux.
  - Auto-created home directories are now created with mode 0777 (and
  directory umask is applied), per common request. It's very important to
  double check your umask.
  - Extend gid / uid to 10 digits in ls output. Extend file size as well.
  - Brazilian portuguese translation was updated.
  - Fix SecureFX compatibility.
  - Use PQescapeStringConn() for PostgreSQL instead of hand-made escaping.
  - Don't respond to server that an upload succeeded before the temporary
  file has been renamed.
  - TLS support on data channels
  - Use sendfile() on recent Solaris versions in place of sendfilev().
  - Don't use a deprecated interface for Bonjour registration.
  - Tell authentication handlers if the connection is encrypted or not,
  through a new AUTHD_ENCRYPTED environment variable.
  - Create all directories, not only the basement when on-demand directory
  creation is enabled and the user's home directory looks like /basement/./user.
  - Fixed error reporting when TLS support was compiled in, but TLS wasn't
  enabled on the current session
  - Log full path on file deletion
  - Handle "ftp" and "anonymous" like normal accounts (with passwords) if -E
  (no anonymous logins) is specified. Thanks to Arkadiusz Miskiewicz.
  - Sleep before answering a password failure, not the other way round
  - In broken mode, show symlinks as their real target. It can have side
  effects, don't forget that broken mode is... broken mode.
  - Respect aliasing rules for sockaddr_storage usage.
  - Privsep is enabled by default in the installation GUI.
  - --with-everything now includes privsep.
  - update: fix compilation with gcc 2.x
* Thu Jan 15 2009 hvogel@suse.de
- Move PassivePortRange to numparic_switch_for [bnc#465954]
* Mon Sep 15 2008 hvogel@suse.de
- limit port range for passv to 30000:30100 to assist firewalling
  [bnc#420671]
* Mon Jul 21 2008 hvogel@suse.de
- do not use tcp send/receive buffer optimization. Might lead to
  strange side effects when allocating too much stack. [bnc#407363]
* Tue Apr  1 2008 mkoenig@suse.de
- remove dir /usr/share/omc/svcinfo.d as it is provided now
  by filesystem
* Thu Mar 20 2008 hvogel@suse.de
- Fix ldap schema [bnc:368864]
- add Short-Description to init script
* Tue Mar 27 2007 mskibbe@suse.de
- change path to firewall script (#247352)
* Fri Mar  2 2007 mskibbe@suse.de
- change path to firewall script (#247352)
* Wed Feb 28 2007 mskibbe@suse.de
- pure-ftpd - Support for FATE #300687: Ports for SuSEfirewall
  added via packages (#246931)
* Thu Jan 11 2007 mskibbe@suse.de
- change path to xml service document (fate #301713)
* Wed Dec  6 2006 mskibbe@suse.de
- add service xml document (fate #301713 )
* Wed Sep  6 2006 mskibbe@suse.de
- fix bug Bug 203798 - Restarting the ftp server using the
  "rcpure-ftpd stop/start" doesn't stop/kill the existing
  client-server instances
* Mon Sep  4 2006 kukuk@suse.de
- Add pam_loginuid.so to session management
* Thu Aug 31 2006 mskibbe@suse.de
- update to version 1.0.21 which
  o includes patch pure-ftpd-1.0.20-abort-transfer.patch
  o Rendezvous has been renamed Bonjour
  o The old PAM sample has been removed
  o -F option added to pure-pw
  o MAX_USER_LENGTH has been bumped to 127 due to popular demand
  o pam/* can now be used if security/* doesn't exist
  o simplify() simplifies paths ending by /. and /..
  o Experimental support for RFC2640 (UTF-8 filename encoding)
  o The LDAP schema has been changed: FTPStatus should be a boolean
  o OPTS MLST has been implemented
  o SITE UTIME has been implemented
  o TCP_CORK is on by default again. A new configure switch,
  - -without-cork, can disable it
  o Correctly format %%c and %%%% in fakesprintf()
  o The connection socket is now created with the Nagle algorithm
    disabled. It was the trick to dramatically improve performance
    when transfering a lot of small files
  o Use CLIENT_MULTI_STATEMENTS while connecting to a MySQL server
* Mon Aug 21 2006 kukuk@suse.de
- Reorder auth section of PAM config file to make sure all modules
  will always be evaluated.
* Mon Apr 10 2006 mrueckert@suse.de
- added pure-ftpd-1.0.20_config_minuid.patch:
  * configuration-file/pure-ftpd.conf.in: our ftp user has uid 40.
    if you want to map virtual users to this uid they would be
    blocked from login.
- added pure-ftpd-1.0.20_ftpwho_path.patch:
  * src/ftpwho-update.h: PAGE_SIZE is a function on
    glibc-2.4/kernel-2.6.16 on ppc64. use PATH_MAX for the filename
    member of the FTPWhoEntry_ struct
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 hvogel@suse.de
- Patch from Patrick Gosling to handle transfer aborts during file
  upload correctly. [#133452]
* Fri Jan 13 2006 hvogel@suse.de
- Make use of Stack Protector
* Mon Oct 24 2005 mrueckert@suse.de
- cleaned up spec file
- add /etc/pure-ftpd/vhosts as base dir for virtual servers.
  (documentation and code changed accordingly.)
- fixed paths in the documenation
* Thu Oct 13 2005 hvogel@suse.de
- Build with DLDAP_DEPRECATED untill upstream applied one of the
  various ldap patches floating around on the sf.net project page
* Wed Aug 24 2005 hvogel@suse.de
- disable "funny" ftp messages to be a bit more professional
* Mon Nov  8 2004 kukuk@suse.de
- Use common-* PAM config files for pure-ftpd PAM configuration
* Thu Aug 12 2004 mmj@suse.de
- Use --with-diraliases
* Thu Aug 12 2004 mmj@suse.de
- Update to 1.0.20 which fixes compatibility issues.
* Wed Jun 23 2004 mmj@suse.de
- Update to 1.0.19 including:
  o Real disk space is no more shown.
  o A possible denial of service when too many users were connected
    should be fixed.
* Tue Mar  2 2004 mmj@suse.de
- Reflect in the configuration file that /etc/pure-ftpd/ now is a
  place to keep all the pure-ftpd configuration files.
* Tue Mar  2 2004 mmj@suse.de
- Move configuration file when updating
- Fix initscript to use /etc/pure-ftpd/pure-ftpd.conf [#35196]
- Update to 1.0.18 including:
  o UTF-8 characters are now supported in file names [#34829]
  o Buglets were fixed in the documentation.
  o Two new translations were added : hungarian and catalan
  o The server now uses distinct IPv4 and IPv6 to listen to both
    protocols on all operating systems. A new switch, -6, forces the
    server to only listen to IPv6.
  o W3C and CLF alternative log formats are now more standard
    conformant.
  o Pure-FTPd can now produce WU-FTPd (xferlog) compatible log files.
  o Support for Rendezvous was added on MacOS X.
  o Support for Apple / GNUStep plist data output was added to
    pure-ftpwho.
* Fri Feb 27 2004 mmj@suse.de
- Enable mysql and postgresql support, since they provide very
  good functionality with only tiny extra dependencies
- Compile with --with-nonalnum to support non alphanumeric chars
* Fri Jan 16 2004 kukuk@suse.de
- Add pam-devel to neededforbuild
* Thu Dec  4 2003 mmj@suse.de
- Update to pure-ftpd v. 1.0.17a
* Wed Oct 15 2003 mmj@suse.de
- Don't build as root
* Tue Aug 12 2003 mmj@suse.de
- Update to 1.0.16, with SSL/TLS support and many bugfixes
- Use new macros for stop/restart of services on rpm update/removal
* Sun Jul 27 2003 mmj@suse.de
- Support system quotas
* Tue Jun 17 2003 mmj@suse.de
- Update to version 1.0.15:
  - A turkish translation has been added.
  - Various functional and portability fixes have been made to the
  handling of upload scripts, to the pure-pw command and to the
  automatic creation of home directories.
  - Accounts in a puredb database can now be quickly listed.
  - The anonymous FTP directory can now be overriden on the Windows
  port (using a WIN32_ANON_DIR environment variable).
  - The default banner has been stripped down to look more
  professionnal.
  - Transfer speed on BSD systems has been improved.
  - The license of the whole package has changed from GPL to a
  simplified BSD license.
* Thu May 15 2003 mmj@suse.de
- Allow dot-files in general, but prohibit writing of them [#26897]
* Wed Apr 30 2003 mmj@suse.de
- Apply the detach patch elsewhere to not break xinetd
- Add note to the xinetd conffile about the xinetd behaviour
- Rearrange the specfile a bit
* Thu Mar  6 2003 mmj@suse.de
- Fix the xinetd configuration file
* Fri Feb 28 2003 mmj@suse.de
- Add note to README.LDAP about use_ldap in the pam config
* Fri Jan 31 2003 mmj@suse.de
- Update to 1.0.14 and add a xinetd configuration file just in case
  the user wants to use it with xinetd. Default behaviour is still
  standalone.
* Mon Jan 20 2003 mmj@suse.de
- Added patch to detach from fd 0, 1 and 2 [#22836]
* Wed Nov 27 2002 mmj@suse.de
- Update to 1.0.13a which is a minor feature/bugfix-release
* Sat Oct  5 2002 ckm@suse.de
- Changed default config file to only allow ro anonymous logins,
  and tightened security in case writing is enabled.
* Sat Aug  3 2002 kukuk@suse.de
- Remove symlinks in postinstall script
- Add PreRequires for insserv
* Thu Jul  4 2002 kukuk@suse.de
- Update to version 1.0.12 (per-user limits)
* Fri Apr 26 2002 kukuk@suse.de
- Update to version 1.0.11 (minor bug fixes, better LDAP support)
* Mon Mar 11 2002 kukuk@suse.de
- Fix permissions
* Sat Feb 16 2002 kukuk@suse.de
- Fix print arguments [Bug #13389]
* Mon Feb 11 2002 ro@suse.de
- flgs in perl-config parser is an array
* Thu Jan 24 2002 kukuk@suse.de
- Update to version 1.0.8
- Compile with LDAP support
* Thu Nov 29 2001 kukuk@suse.de
- Add pam config file
- Cleanup example config file
* Thu Nov 22 2001 kukuk@suse.de
- Update to 1.0.3 (rename and quota fixes)
* Thu Nov  1 2001 kukuk@suse.de
- Initial release of a secure ftp server with LFS
